[−][src]Module storagevec::smap
Contains the StorageMap; a feature-gated map structure that alternates between stack and heap
storage depending on the alloc feature.
Structs
| StorageMap | A map object that with either use the tinymap |
Contains the StorageMap; a feature-gated map structure that alternates between stack and heap
storage depending on the alloc feature.
| StorageMap | A map object that with either use the tinymap |