[−][src]Module storagevec::svec
Contains the StorageVec; a feature-gated vector structure that alternates between stack and heap
storage depending on the alloc feature.
Structs
| StorageVec | A list-like object that will either use the tinyvec |
| StorageVecIterator | An owning iterator for the |